@@ -3,18 +3,13 @@ from django.contrib.auth.models import User
 from hitcount.models import HitCountMixin, HitCount
 from taggit.managers import TaggableManager
 from django.contrib.contenttypes.fields import GenericRelation
+from _data.blog import CATEGORY
 
 STATUS = (
     (0, "Draft"),
     (1, "Publish")
 )
 
-CATEGORY = (
-    (0, "Dental"),
-    (1, "Development"),
-)
-
-
 class Post(models.Model):
     title = models.CharField(max_length=200, unique=False)
     slug = models.SlugField(max_length=200, unique=True, allow_unicode=True)
